@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2014-2025 Mike Fährmann
+# Copyright 2014-2026 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -9,7 +9,7 @@
 """Extractors for https://www.imagebam.com/"""
 
 from .common import Extractor, Message
-from .. import text, util
+from .. import text, exception
 
 
 class ImagebamExtractor(Extractor):
@@ -28,14 +28,14 @@ class ImagebamExtractor(Extractor):
     def _parse_image_page(self, path):
         page = self.request(self.root + path).text
         url, pos = text.extract(page, '<img src="https://images', '"')
+        if not url:
+            raise exception.NotFoundError("image")
         filename = text.unescape(text.extract(page, 'alt="', '"', pos)[0])
 
-        data = {
+        return text.nameext_from_name(filename, {
             "url"      : "https://images" + url,
             "image_key": path.rpartition("/")[2],
-        }
-        data["filename"], _, data["extension"] = filename.rpartition(".")
-        return data
+        })
 
 
 class ImagebamGalleryExtractor(ImagebamExtractor):
@@ -49,7 +49,7 @@ class ImagebamGalleryExtractor(ImagebamExtractor):
     example = "https://www.imagebam.com/view/GID"
 
     def items(self):
-        page = self.request(self.root + self.path).text
+        page = self.request(self.root + self.path, notfound=True).text
 
         images = self.images(page)
         images.reverse()
@@ -58,7 +58,7 @@ class ImagebamGalleryExtractor(ImagebamExtractor):
         data["count"] = len(images)
         data["gallery_key"] = self.path.rpartition("/")[2]
 
-        yield Message.Directory, data
+        yield Message.Directory, "", data
         for data["num"], path in enumerate(images, 1):
             image = self._parse_image_page(path)
             image.update(data)
@@ -69,7 +69,7 @@ class ImagebamGalleryExtractor(ImagebamExtractor):
             page, 'id="gallery-name">', '<').strip())}
 
     def images(self, page):
-        findall = util.re(r'<a href="https://www\.imagebam\.com'
+        findall = text.re(r'<a href="https://www\.imagebam\.com'
                           r'(/(?:image/|view/M)[a-zA-Z0-9]+)').findall
         paths = []
         while True:
@@ -96,5 +96,5 @@ class ImagebamImageExtractor(ImagebamExtractor):
             path = ("/view/" if path[10] == "M" else "/image/") + path[10:]
 
         image = self._parse_image_page(path)
-        yield Message.Directory, image
+        yield Message.Directory, "", image
         yield Message.Url, image["url"], image
