@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2018-2023 Mike Fährmann
+# Copyright 2018-2025 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -9,7 +9,7 @@
 """Extractors for https://rule34.paheal.net/"""
 
 from .common import Extractor, Message
-from .. import text
+from .. import text, exception
 
 
 class PahealExtractor(Extractor):
@@ -31,7 +31,7 @@ class PahealExtractor(Extractor):
             post["width"] = text.parse_int(post["width"])
             post["height"] = text.parse_int(post["height"])
             post.update(data)
-            yield Message.Directory, post
+            yield Message.Directory, "", post
             yield Message.Url, post["file_url"], post
 
     def get_metadata(self):
@@ -42,7 +42,7 @@ class PahealExtractor(Extractor):
         """Return an iterable containing data of all relevant posts"""
 
     def _extract_post(self, post_id):
-        url = "{}/post/view/{}".format(self.root, post_id)
+        url = f"{self.root}/post/view/{post_id}"
         extr = text.extract_from(self.request(url).text)
 
         post = {
@@ -53,8 +53,7 @@ class PahealExtractor(Extractor):
                          extr("<source src='", "'")),
             "uploader": text.unquote(extr(
                 "class='username' href='/user/", "'")),
-            "date"    : text.parse_datetime(
-                extr("datetime='", "'"), "%Y-%m-%dT%H:%M:%S%z"),
+            "date"    : self.parse_datetime_iso(extr("datetime='", "'")),
             "source"  : text.unescape(text.extr(
                 extr(">Source Link<", "</td>"), "href='", "'")),
         }
@@ -64,7 +63,7 @@ class PahealExtractor(Extractor):
         post["width"], _, height = dimensions.partition("x")
         post["height"], _, duration = height.partition(", ")
         post["duration"] = text.parse_float(duration[:-1])
-        post["filename"] = "{} - {}".format(post_id, post["tags"])
+        post["filename"] = f"{post_id} - {post['tags']}"
         post["extension"] = ext
 
         return post
@@ -77,24 +76,32 @@ class PahealTagExtractor(PahealExtractor):
     pattern = (r"(?:https?://)?(?:rule34|rule63|cosplay)\.paheal\.net"
                r"/post/list/([^/?#]+)")
     example = "https://rule34.paheal.net/post/list/TAG/1"
+    page_start = 1
     per_page = 70
 
-    def __init__(self, match):
-        PahealExtractor.__init__(self, match)
-        self.tags = text.unquote(match.group(1))
-
     def _init(self):
         if self.config("metadata"):
             self._extract_data = self._extract_data_ex
 
+    def skip(self, num):
+        pages = num // self.per_page
+        self.page_start += pages
+        return pages * self.per_page
+
     def get_metadata(self):
-        return {"search_tags": self.tags}
+        return {"search_tags": text.unquote(self.groups[0])}
 
     def get_posts(self):
-        pnum = 1
+        pnum = self.page_start
+        base = f"{self.root}/post/list/{self.groups[0]}/"
+
         while True:
-            url = "{}/post/list/{}/{}".format(self.root, self.tags, pnum)
-            page = self.request(url).text
+            try:
+                page = self.request(base + str(pnum)).text
+            except exception.HttpError as exc:
+                if exc.status == 404:
+                    return
+                raise
 
             pos = page.find("id='image-list'")
             for post in text.extract_iter(
@@ -105,8 +112,7 @@ class PahealTagExtractor(PahealExtractor):
                 return
             pnum += 1
 
-    @staticmethod
-    def _extract_data(post):
+    def _extract_data(self, post):
         pid , pos = text.extract(post, "", "'")
         data, pos = text.extract(post, "title='", "'", pos)
         md5 , pos = text.extract(post, "/_thumbs/", "/", pos)
@@ -126,8 +132,8 @@ class PahealTagExtractor(PahealExtractor):
             "duration" : text.parse_float(duration[:-1]),
             "tags"     : text.unescape(tags),
             "size"     : text.parse_bytes(size[:-1]),
-            "date"     : text.parse_datetime(date, "%B %d, %Y; %H:%M"),
-            "filename" : "{} - {}".format(pid, tags),
+            "date"     : self.parse_datetime(date, "%B %d, %Y; %H:%M"),
+            "filename" : f"{pid} - {tags}",
             "extension": ext,
         }
 
@@ -143,9 +149,10 @@ class PahealPostExtractor(PahealExtractor):
                r"/post/view/(\d+)")
     example = "https://rule34.paheal.net/post/view/12345"
 
-    def __init__(self, match):
-        PahealExtractor.__init__(self, match)
-        self.post_id = match.group(1)
-
     def get_posts(self):
-        return (self._extract_post(self.post_id),)
+        try:
+            return (self._extract_post(self.groups[0]),)
+        except exception.HttpError as exc:
+            if exc.status == 404:
+                return ()
+            raise
