@@ -18,15 +18,13 @@ class WeasylExtractor(Extractor):
     filename_fmt = "{submitid} {title}.{extension}"
     archive_fmt = "{submitid}"
     root = "https://www.weasyl.com"
-    useragent = util.USERAGENT
+    useragent = util.USERAGENT_GALLERYDL
 
-    @staticmethod
-    def populate_submission(data):
+    def populate_submission(self, data):
         # Some submissions don't have content and can be skipped
         if "submission" in data["media"]:
             data["url"] = data["media"]["submission"][0]["url"]
-            data["date"] = text.parse_datetime(
-                data["posted_at"][:19], "%Y-%m-%dT%H:%M:%S")
+            data["date"] = self.parse_datetime_iso(data["posted_at"][:19])
             text.nameext_from_url(data["url"], data)
             return True
         return False
@@ -35,27 +33,27 @@ class WeasylExtractor(Extractor):
         self.session.headers['X-Weasyl-API-Key'] = self.config("api-key")
 
     def request_submission(self, submitid):
-        return self.request(
-            "{}/api/submissions/{}/view".format(self.root, submitid)).json()
+        return self.request_json(
+            f"{self.root}/api/submissions/{submitid}/view")
 
     def retrieve_journal(self, journalid):
-        data = self.request(
-            "{}/api/journals/{}/view".format(self.root, journalid)).json()
+        data = self.request_json(
+            f"{self.root}/api/journals/{journalid}/view")
         data["extension"] = "html"
         data["html"] = "text:" + data["content"]
-        data["date"] = text.parse_datetime(data["posted_at"])
+        data["date"] = self.parse_datetime_iso(data["posted_at"])
         return data
 
     def submissions(self, owner_login, folderid=None):
         metadata = self.config("metadata")
-        url = "{}/api/users/{}/gallery".format(self.root, owner_login)
+        url = f"{self.root}/api/users/{owner_login}/gallery"
         params = {
             "nextid"  : None,
             "folderid": folderid,
         }
 
         while True:
-            data = self.request(url, params=params).json()
+            data = self.request_json(url, params=params)
             for submission in data["submissions"]:
                 if metadata:
                     submission = self.request_submission(
@@ -77,12 +75,12 @@ class WeasylSubmissionExtractor(WeasylExtractor):
 
     def __init__(self, match):
         WeasylExtractor.__init__(self, match)
-        self.submitid = match.group(1)
+        self.submitid = match[1]
 
     def items(self):
         data = self.request_submission(self.submitid)
         if self.populate_submission(data):
-            yield Message.Directory, data
+            yield Message.Directory, "", data
             yield Message.Url, data["url"], data
 
 
@@ -93,10 +91,10 @@ class WeasylSubmissionsExtractor(WeasylExtractor):
 
     def __init__(self, match):
         WeasylExtractor.__init__(self, match)
-        self.owner_login = match.group(1)
+        self.owner_login = match[1]
 
     def items(self):
-        yield Message.Directory, {"owner_login": self.owner_login}
+        yield Message.Directory, "", {"owner_login": self.owner_login}
         yield from self.submissions(self.owner_login)
 
 
@@ -115,7 +113,7 @@ class WeasylFolderExtractor(WeasylExtractor):
         # Folder names are only on single submission api calls
         msg, url, data = next(iter)
         details = self.request_submission(data["submitid"])
-        yield Message.Directory, details
+        yield Message.Directory, "", details
         yield msg, url, data
         yield from iter
 
@@ -129,11 +127,11 @@ class WeasylJournalExtractor(WeasylExtractor):
 
     def __init__(self, match):
         WeasylExtractor.__init__(self, match)
-        self.journalid = match.group(1)
+        self.journalid = match[1]
 
     def items(self):
         data = self.retrieve_journal(self.journalid)
-        yield Message.Directory, data
+        yield Message.Directory, "", data
         yield Message.Url, data["html"], data
 
 
@@ -146,12 +144,12 @@ class WeasylJournalsExtractor(WeasylExtractor):
 
     def __init__(self, match):
         WeasylExtractor.__init__(self, match)
-        self.owner_login = match.group(1)
+        self.owner_login = match[1]
 
     def items(self):
-        yield Message.Directory, {"owner_login": self.owner_login}
+        yield Message.Directory, "", {"owner_login": self.owner_login}
 
-        url = "{}/journals/{}".format(self.root, self.owner_login)
+        url = f"{self.root}/journals/{self.owner_login}"
         page = self.request(url).text
         for journalid in text.extract_iter(page, 'href="/journal/', '/'):
             data = self.retrieve_journal(journalid)
@@ -193,12 +191,12 @@ class WeasylFavoriteExtractor(WeasylExtractor):
                 submission = self.request_submission(submitid)
                 if self.populate_submission(submission):
                     submission["user"] = owner_login
-                    yield Message.Directory, submission
+                    yield Message.Directory, "", submission
                     yield Message.Url, submission["url"], submission
 
             try:
                 pos = page.index('">Next (', pos)
             except ValueError:
                 return
-            path = text.unescape(text.rextract(page, 'href="', '"', pos)[0])
+            path = text.unescape(text.rextr(page, 'href="', '"', pos))
             params = None
