@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2025 Mike Fährmann
+# Copyright 2025-2026 Mike Fährmann
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -18,13 +18,13 @@ class XenforoExtractor(BaseExtractor):
     basecategory = "xenforo"
     directory_fmt = ("{category}", "{thread[section]}",
                      "{thread[title]} ({thread[id]})")
-    filename_fmt = "{post[id]}_{num:>02}_{id}_{filename}.{extension}"
+    filename_fmt = "{post[id]}_{num:>02}{id:?_//}_{filename}.{extension}"
     archive_fmt = "{post[id]}/{type[0]}{id}_{filename}"
 
     def __init__(self, match):
         BaseExtractor.__init__(self, match)
         self.cookies_domain = "." + self.root.split("/")[2]
-        self.cookies_names = self.config_instance("cookies")
+        self.cookies_names = self.config_instance("cookies") or ("xf_user",)
 
     def items(self):
         self.login()
@@ -32,16 +32,17 @@ class XenforoExtractor(BaseExtractor):
         extract_urls = text.re(
             r'(?s)(?:'
             r'<video (.*?\ssrc="[^"]+".*?)</video>'
-            r'|<a [^>]*?href="[^"]*?'
-            r'(/(?:index\.php\?)?attachments/[^"]+".*?)</a>'
-            r'|<div [^>]*?data-src="[^"]*?'
-            r'(/(?:index\.php\?)attachments/[^"]+".*?)/>'
+            r'|<a [^>]*?'
+            r'href="([^"]*?/(?:index\.php\?)?attachments/[^"]+".*?)</a>'
+            r'|<div class="bb(?:Image|Media)Wrapper[^>]*?'
+            r'data-src="([^"]+".*?) />'
             r'|(?:<a [^>]*?href="|<iframe [^>]*?src="|'
             r'''onclick="loadMedia\(this, ')([^"']+)'''
             r')'
         ).findall
 
-        root_media = self.config_instance("root-media") or self.root
+        root = self.root
+        base = root if (pos := root.find("/", 8)) < 0 else root[:pos]
         for post in self.posts():
             urls = extract_urls(post["content"])
             if post["attachments"]:
@@ -55,16 +56,18 @@ class XenforoExtractor(BaseExtractor):
             data["_http_expected_status"] = (403,)
             data["_http_validate"] = self._validate
             data["num"] = data["num_internal"] = data["num_external"] = 0
-            for video, inl1, inl2, ext in urls:
+            for video, inl, bb, ext in urls:
                 if ext:
-                    data["num"] += 1
-                    data["num_external"] += 1
-                    data["type"] = "external"
+                    if ext[0] == "#":
+                        continue
                     if ext[0] == "/":
                         if ext[1] == "/":
                             ext = "https:" + ext
                         else:
                             continue
+                    data["num"] += 1
+                    data["num_external"] += 1
+                    data["type"] = "external"
                     yield Message.Queue, ext, data
 
                 elif video:
@@ -76,19 +79,20 @@ class XenforoExtractor(BaseExtractor):
                     data["id"] = text.parse_int(
                         data["filename"].partition("-")[0])
                     if url[0] == "/":
-                        url = root_media + url
+                        url = base + url
                     yield Message.Url, url, data
 
-                elif (inline := inl1 or inl2):
-                    path = inline[:inline.find('"')]
-                    name, _, id = path[path.rfind("/", 0, -1):].strip(
+                elif (inline := bb or inl):
+                    url = inline[:inline.find('"')]
+                    name, _, id = url[url.rfind("/", 0, -1):].strip(
                         "/").rpartition(".")
-                    if id == id_last:
-                        id_last = None
-                        continue
-                    else:
-                        id_last = id
-                    data["id"] = text.parse_int(id)
+                    data["id"] = id = text.parse_int(id)
+                    if id:
+                        if id == id_last:
+                            id_last = None
+                            continue
+                        else:
+                            id_last = id
                     if alt := text.extr(inline, 'alt="', '"'):
                         text.nameext_from_name(alt, data)
                         if not data["extension"]:
@@ -99,7 +103,47 @@ class XenforoExtractor(BaseExtractor):
                     data["num"] += 1
                     data["num_internal"] += 1
                     data["type"] = "inline"
-                    yield Message.Url, self.root + path, data
+                    if url[0] == "/":
+                        url = base + url
+                    yield Message.Url, url, data
+
+    def items_media(self, path, pnum, callback=None):
+        if (order := self.config("order-posts")) and \
+                order[0] in ("d", "r"):
+            pages = self._pagination_reverse(path, pnum, callback)
+            reverse = True
+        else:
+            pages = self._pagination(path, pnum, callback)
+            reverse = False
+
+        if self.config("metadata"):
+            extr_media = self._extract_media_ex
+            meta = True
+        else:
+            extr_media = self._extract_media
+            meta = False
+
+        root = self.root
+        base = root if (pos := root.find("/", 8)) < 0 else root[:pos]
+        for page in pages:
+            posts = page.split(
+                '<div class="itemList-item js-inlineModContainer')
+            del posts[0]
+
+            if reverse:
+                posts.reverse()
+
+            for html in posts:
+                href, pos = text.extract(html, 'href="', '"')
+                name, pos = text.extract(html, "alt='", "'", pos)
+
+                url, media = extr_media(
+                    base + href, href[href.rfind("/", 0, -1)+1:-1])
+                if not meta and name:
+                    text.nameext_from_name(text.unescape(name), media)
+
+                yield Message.Directory, "", media
+                yield Message.Url, url, media
 
     def request_page(self, url):
         try:
@@ -110,7 +154,7 @@ class XenforoExtractor(BaseExtractor):
             raise
 
     def login(self):
-        if self.cookies_check(self.cookies_names):
+        if self.cookies_names and self.cookies_check(self.cookies_names):
             return
 
         username, password = self._get_auth_info()
@@ -142,7 +186,7 @@ class XenforoExtractor(BaseExtractor):
             if cookie.domain.endswith(self.cookies_domain)
         }
 
-    def _pagination(self, base, pnum=None):
+    def _pagination(self, base, pnum=None, callback=None):
         base = self.root + base
 
         if pnum is None:
@@ -152,17 +196,18 @@ class XenforoExtractor(BaseExtractor):
             url = f"{base}/page-{pnum}"
             pnum = None
 
+        page = self.request_page(url).text
+        if callback is not None:
+            callback(page)
         while True:
-            page = self.request_page(url).text
-
             yield page
 
             if pnum is None or "pageNav-jump--next" not in page:
                 return
             pnum += 1
-            url = f"{base}/page-{pnum}"
+            page = self.request_page(f"{base}/page-{pnum}").text
 
-    def _pagination_reverse(self, base, pnum=None):
+    def _pagination_reverse(self, base, pnum=None, callback=None):
         base = self.root + base
 
         url = f"{base}/page-{'9999' if pnum is None else pnum}"
@@ -176,6 +221,8 @@ class XenforoExtractor(BaseExtractor):
                 pnum = text.parse_int(url[url.rfind("-")+1:], 1)
             page = response.text
 
+        if callback is not None:
+            callback(page)
         while True:
             yield page
 
@@ -193,41 +240,6 @@ class XenforoExtractor(BaseExtractor):
         return text.unescape(text.extr(
             html, "blockMessage--error", "</").rpartition(">")[2].strip())
 
-    def _parse_thread(self, page):
-        try:
-            data = self._extract_jsonld(page)
-        except ValueError:
-            return {}
-
-        schema = data.get("mainEntity", data)
-        author = schema["author"]
-        stats = schema["interactionStatistic"]
-        url_t = schema.get("url") or schema.get("@id") or ""
-        url_a = author.get("url") or ""
-
-        thread = {
-            "id"   : url_t[url_t.rfind(".")+1:-1],
-            "url"  : url_t,
-            "title": schema["headline"],
-            "date" : self.parse_datetime_iso(schema["datePublished"]),
-            "tags" : (schema["keywords"].split(", ")
-                      if "keywords" in schema else ()),
-            "section"   : schema["articleSection"],
-            "author"    : author.get("name") or "",
-            "author_id" : (url_a[url_a.rfind(".")+1:-1] if url_a else
-                           (author.get("name") or "")[15:]),
-            "author_url": url_a,
-        }
-
-        if isinstance(stats, list):
-            thread["views"] = stats[0]["userInteractionCount"]
-            thread["posts"] = stats[1]["userInteractionCount"]
-        else:
-            thread["views"] = -1
-            thread["posts"] = stats["userInteractionCount"]
-
-        return thread
-
     def _parse_post(self, html):
         extr = text.extract_from(html)
 
@@ -244,7 +256,8 @@ class XenforoExtractor(BaseExtractor):
         }
 
         url_a = post["author_url"]
-        post["author_id"] = url_a[url_a.rfind(".")+1:-1]
+        post["author_slug"], _, post["author_id"] = \
+            url_a[url_a.rfind("/", 0, -1)+1:-1].rpartition(".")
 
         con = post["content"]
         if (pos := con.find('<div class="bbWrapper')) >= 0:
@@ -253,6 +266,106 @@ class XenforoExtractor(BaseExtractor):
 
         return post
 
+    def _parse_thread(self, page):
+        try:
+            data = self._extract_jsonld(page)
+        except ValueError:
+            return {}
+
+        main = data.get("mainEntity", data)
+        url = main.get("url") or main.get("@id") or ""
+
+        self.kwdict["thread"] = thread = self._parse_author(main["author"], {
+            "id"   : url[url.rfind(".")+1:-1],
+            "url"  : url,
+            "title": main["headline"],
+            "date" : self.parse_datetime_iso(main["datePublished"]),
+            "tags" : (main["keywords"].split(", ")
+                      if "keywords" in main else ()),
+            "section": main["articleSection"],
+        })
+
+        stats = main["interactionStatistic"]
+        if isinstance(stats, list):
+            thread["views"] = stats[0]["userInteractionCount"]
+            thread["posts"] = stats[1]["userInteractionCount"]
+        else:
+            thread["views"] = -1
+            thread["posts"] = stats["userInteractionCount"]
+
+        return thread
+
+    def _parse_album(self, page):
+        main = self._extract_jsonld(page)["mainEntity"]
+        url = main.get("url") or main.get("@id") or ""
+        slug, _, id = url[url.rfind("/", 0, -1)+1:-1].rpartition(".")
+
+        self.kwdict["album"] = album = self._parse_author(main["author"], {
+            "id"   : id,
+            "url"  : url,
+            "slug" : text.unquote(slug),
+            "title": main["headline"],
+            "description": main.get("description"),
+            "date": self.parse_datetime_iso(main["dateCreated"]),
+        })
+
+        stats = main["interactionStatistic"]
+        if isinstance(stats, list):
+            album["count"] = stats[0]["userInteractionCount"]
+            album["likes"] = stats[1]["userInteractionCount"]
+            album["views"] = stats[2]["userInteractionCount"]
+            album["comments"] = stats[3]["userInteractionCount"]
+
+        return album
+
+    def _parse_author(self, author, data):
+        data["author"] = author.get("name") or ""
+        if url := author.get("url"):
+            data["author_url"] = url
+            data["author_slug"], _, data["author_id"] = \
+                url[url.rfind("/", 0, -1)+1:-1].rpartition(".")
+        else:
+            data["author_url"] = ""
+            data["author_slug"] = text.slugify(data["author"][:15])
+            data["author_id"] = data["author"][15:]
+        return data
+
+    def _extract_media(self, url, file):
+        media = {}
+        name, _, media["id"] = file.rpartition(".")
+        media["filename"], _, media["extension"] = name.rpartition("-")
+        return url + "full", media
+
+    def _extract_media_ex(self, url, file):
+        page = self.request(url).text
+
+        schema = self._extract_jsonld(page)
+        main = schema["mainEntity"]
+        stats = main["interactionStatistic"]
+
+        media = text.nameext_from_name(main["name"], {
+            "schema": schema,
+            "id"    : file.rpartition(".")[2],
+            "size"  : main.get("contentSize"),
+            "description": main.get("description"),
+            "date"  : self.parse_datetime_iso(main.get("dateCreated")),
+            "width" : (w := main.get("width")) and text.parse_int(
+                w["name"].partition(" ")[0]) or 0,
+            "height": (h := main.get("height")) and text.parse_int(
+                h["name"].partition(" ")[0]) or 0,
+        })
+
+        self._parse_author(main["author"], media)
+        if ext := main.get("encodingFormat"):
+            media["extension"] = ext
+
+        if isinstance(stats, list):
+            media["views"] = stats[0]["userInteractionCount"]
+            media["likes"] = stats[1]["userInteractionCount"]
+            media["comments"] = stats[2]["userInteractionCount"]
+
+        return main["contentUrl"], media
+
     def _require_auth(self, response=None):
         raise exception.AuthRequired(
             ("username & password", "authenticated cookies"), None,
@@ -273,13 +386,14 @@ BASE_PATTERN = XenforoExtractor.update({
     "nudostarforum": {
         "root": "https://nudostar.com/forum",
         "pattern": r"(?:www\.)?nudostar\.com/forum",
-        "cookies": ("xf_user",),
     },
     "atfforum": {
         "root": "https://allthefallen.moe/forum",
-        "root-media": "https://allthefallen.moe",
         "pattern": r"(?:www\.)?allthefallen\.moe/forum",
-        "cookies": ("xf_user",),
+    },
+    "celebforum": {
+        "root": "https://celebforum.to",
+        "pattern": r"(?:www\.)?celebforum\.to",
     },
 })
 
@@ -301,7 +415,7 @@ class XenforoPostExtractor(XenforoExtractor):
             raise exception.NotFoundError("post")
         html = text.extract(page, "<article ", "<footer", pos-200)[0]
 
-        self.kwdict["thread"] = self._parse_thread(page)
+        self._parse_thread(page)
         return (self._parse_post(html),)
 
 
@@ -325,7 +439,7 @@ class XenforoThreadExtractor(XenforoExtractor):
 
         for page in pages:
             if "thread" not in self.kwdict:
-                self.kwdict["thread"] = self._parse_thread(page)
+                self._parse_thread(page)
             posts = text.extract_iter(page, "<article ", "<footer")
             if reverse:
                 posts = list(posts)
@@ -350,3 +464,76 @@ class XenforoForumExtractor(XenforoExtractor):
         for page in self._pagination(path, pnum):
             for path in extract_threads(page):
                 yield Message.Queue, self.root + text.unquote(path), data
+
+
+class XenforoMediaUserExtractor(XenforoExtractor):
+    subcategory = "media-user"
+    directory_fmt = ("{category}", "Media", "{author_slug}")
+    filename_fmt = "{filename}.{extension}"
+    archive_fmt = "{id}"
+    pattern = (BASE_PATTERN + r"(/(?:index\.php\?)?)me(?:"
+               r"dia/users/([^/?#]+)(?:/page-(\d+))?|"
+               r"mbers/([^/?#]+)/#xfmgMedia)")
+    example = "https://simpcity.cr/media/users/USER.123/"
+
+    def items(self):
+        groups = self.groups
+
+        user = groups[-3]
+        if user is None:
+            user = groups[-1]
+            pnum = None
+        else:
+            pnum = groups[-2]
+
+        if not self.config("metadata"):
+            self.kwdict["author_slug"], _, self.kwdict["author_id"] = \
+                user.rpartition(".")
+
+        return self.items_media(f"{groups[-4]}media/users/{user}", pnum)
+
+
+class XenforoMediaAlbumExtractor(XenforoExtractor):
+    subcategory = "media-album"
+    directory_fmt = ("{category}", "Media", "Albums",
+                     "{album[slug]} ({album[id]})")
+    filename_fmt = "{filename}.{extension}"
+    archive_fmt = "{id}"
+    pattern = (BASE_PATTERN + r"(/(?:index\.php\?)?"
+               r"media/albums/([^/?#]+))(?:/page-(\d+))?")
+    example = "https://simpcity.cr/media/albums/ALBUM.123/"
+
+    def items(self):
+        return self.items_media(
+            self.groups[-3], self.groups[-1], self._parse_album)
+
+
+class XenforoMediaCategoryExtractor(XenforoExtractor):
+    subcategory = "media-category"
+    directory_fmt = ("{category}", "Media", "Category", "{mcategory}")
+    filename_fmt = "{filename}.{extension}"
+    archive_fmt = "{id}"
+    pattern = (BASE_PATTERN + r"(/(?:index\.php\?)?"
+               r"media/categories/([^/?#]+))(?:/page-(\d+))?")
+    example = "https://simpcity.cr/media/categories/CATEGORY.123/"
+
+    def items(self):
+        self.kwdict["mcategory"], _, self.kwdict["mcategory_id"] = \
+            self.groups[-2].rpartition(".")
+        return self.items_media(self.groups[-3], self.groups[-1])
+
+
+class XenforoMediaItemExtractor(XenforoExtractor):
+    subcategory = "media-item"
+    directory_fmt = ("{category}", "Media", "{author_slug|''}")
+    filename_fmt = "{filename}.{extension}"
+    archive_fmt = "{id}"
+    pattern = BASE_PATTERN + r"(/(?:index\.php\?)?media/((?:[^/?#]+\.)\d+))"
+    example = "https://simpcity.cr/media/NAME.123/"
+
+    def items(self):
+        url = f"{self.root}{self.groups[-2]}/"
+        url, media = (self._extract_media_ex if self.config("metadata") else
+                      self._extract_media)(url, self.groups[-1])
+        yield Message.Directory, "", media
+        yield Message.Url, url, media
